summaryrefslogtreecommitdiffstats
path: root/components/signin
diff options
context:
space:
mode:
authorblundell@chromium.org <blundell@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-03-21 17:23:34 +0000
committerblundell@chromium.org <blundell@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-03-21 17:23:34 +0000
commit671f6db78908d493c1aabc3b8c3be6f4598fed73 (patch)
tree664675bc106e43398f96cbaefc2aace93353453f /components/signin
parent8a585cbb238840eadf792f120d1b80a321b37220 (diff)
downloadchromium_src-671f6db78908d493c1aabc3b8c3be6f4598fed73.zip
chromium_src-671f6db78908d493c1aabc3b8c3be6f4598fed73.tar.gz
chromium_src-671f6db78908d493c1aabc3b8c3be6f4598fed73.tar.bz2
Eliminate ProfileOAuth2TokenServiceWrapper.
ProfileOAuth2TokenService can now directly be a KeyedService that is shared by iOS, so the wrapper is no longer needed. The two functions for building a FakeProfileOAuth2TokenService for a given BrowserContext are placed in a new fake_profile_oauth2_token_service_builder.* file, since fake_profile_oauth2_token_service will be componentized but those functions will not be. BUG=350709 TBR=thakis Review URL: https://codereview.chromium.org/201123002 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@258616 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'components/signin')
-rw-r--r--components/signin/core/mutable_profile_oauth2_token_service.h2
-rw-r--r--components/signin/core/profile_oauth2_token_service.h8
2 files changed, 6 insertions, 4 deletions
diff --git a/components/signin/core/mutable_profile_oauth2_token_service.h b/components/signin/core/mutable_profile_oauth2_token_service.h
index b9ebc6e..9222dfc 100644
--- a/components/signin/core/mutable_profile_oauth2_token_service.h
+++ b/components/signin/core/mutable_profile_oauth2_token_service.h
@@ -67,7 +67,7 @@ class MutableProfileOAuth2TokenService : public ProfileOAuth2TokenService,
// to information about the account.
typedef std::map<std::string, linked_ptr<AccountInfo> > AccountInfoMap;
- friend class ProfileOAuth2TokenServiceWrapperImpl;
+ friend class ProfileOAuth2TokenServiceFactory;
MutableProfileOAuth2TokenService();
virtual ~MutableProfileOAuth2TokenService();
diff --git a/components/signin/core/profile_oauth2_token_service.h b/components/signin/core/profile_oauth2_token_service.h
index b4ede3a..526c3cd 100644
--- a/components/signin/core/profile_oauth2_token_service.h
+++ b/components/signin/core/profile_oauth2_token_service.h
@@ -20,7 +20,7 @@ class URLRequestContextGetter;
class GoogleServiceAuthError;
class SigninClient;
// ProfileOAuth2TokenService is a class that retrieves
// OAuth2 access tokens for a given set of scopes using the OAuth2 login
// refresh tokens.
//
@@ -34,14 +34,16 @@ class SigninClient;
//
// Note: requests should be started from the UI thread. To start a
// request from other thread, please use ProfileOAuth2TokenServiceRequest.
-class ProfileOAuth2TokenService : public OAuth2TokenService {
+class ProfileOAuth2TokenService : public OAuth2TokenService,
+ public KeyedService {
public:
virtual ~ProfileOAuth2TokenService();
// Initializes this token service with the SigninClient.
virtual void Initialize(SigninClient* client);
- virtual void Shutdown();
+ // KeyedService implementation.
+ virtual void Shutdown() OVERRIDE;
// Lists account IDs of all accounts with a refresh token.
virtual std::vector<std::string> GetAccounts() OVERRIDE;
@@ -20,7 +20,7 @@ class URLRequestContextGetter;
class GoogleServiceAuthError;
class SigninClient;
-// ProfileOAuth2TokenService is a class that retrieves
+// ProfileOAuth2TokenService is a KeyedService that retrieves
// OAuth2 access tokens for a given set of scopes using the OAuth2 login
// refresh tokens.